@@ -1,4 +1,5 @@
 from shutil import get_terminal_size
+from time import sleep
 from typing import Optional
 
 
@@ -73,7 +74,7 @@ class Logger:
 	@staticmethod
 	def _make_print_str(*values: object, sep=None) -> str:
 		# this function is for reduce number of the same calculations
-		return (sep if sep else ' ').join(str(v) for v in values)
+		return (sep or ' ').join(str(v) for v in values)
 
 	def _print(
 		self,
@@ -96,8 +97,9 @@ class Logger:
 			to_print.insert(0, self._log_prefix)
 		to_print_str = self._make_print_str(*to_print, sep=sep)
 
-		spaces_offset = self._term_width() - len(to_print_str) + 1
-		self._print_func(to_print_str + ' ' * spaces_offset, end=end)
+		spaces_offset = self._term_width() - len(to_print_str) - 1
+		# print(len(to_print_str), spaces_offset, f'last: "{to_print_str[-1]}"')
+		self._print_func(to_print_str + ' ' * spaces_offset + 'a', end=end)
 
 		if prefix is not None:
 			self._restore_prefix()
